# Example use in Jupyter notebooks

Recommended to run using [uv](https://docs.astral.sh/uv/):
```
uv run jupyter lab
```

## Notebooks

- `minimal-example.ipynb`: basic example from the teaser image, no dependencies
or input files, just a randomly generated structure.
- `inputs.ipynb`: shows different ways to input data into the widget
- `polychrom.ipynb`: example of interfacing with a simulation engine (TODO)
